module FundRaise

require_relative '../../lib/fund_raise/project'
require_relative '../../lib/fund_raise/funding_round'
require_relative '../../lib/fund_raise/die'
require_relative '../../lib/fund_raise/pledge_pool'

class FundRequest
  attr_accessor :name
  attr_reader :projects_ar

  def initialize (mylistname)
    @name = mylistname
    @projects_ar = []
  end

  def add_project(project)
   @projects_ar.push(project)
  end

  def load_projects(from_file)
    File.readlines(from_file).each do |line|
    add_project(Project.from_csv(line))
    end
  end

  def request_funding(rounds)
    PledgePool::print_pledges_available
    puts "Project List: #{@name}:"

    1.upto(rounds) do |round|
      puts"\nRound #{round}"
      @projects_ar.each do |project|
        puts project
        FundingRound.one_round(project)
      puts "#{project}\n\n"
      end
    end
  end

  def save_under_funded(to_file="under_funded.txt")
    File.open(to_file, "w") do |file|
      file.puts "#{@name}'s Under-funded projects:"

      @projects_ar.sort.each do |p|
        if !p.fully_funded?
        file.puts underfunded_entry(p)
        end
      end
    end
  end

  def underfunded_entry(project)
    formatted_name = project.name.ljust(20, '.')
    "#{formatted_name} $#{project.funding_left} needed"
  end

  def print_stats
    fully, not_fully = @projects_ar.partition { |project| project.fully_funded? }

    puts "\n#{@name}'s funding:"

    @projects_ar.sort.each do |p|
    puts "\n#{p.name}'s total funding is $#{p.total_funding}"
      p.each_given_pledge do |pl|
        puts "#{pl.value} total #{pl.name} points"
      end
    end
      
      puts "\nThese projects are fully funded:"
      fully.sort.each do |p|
        puts "#{p.name}"
      end
    
      puts "\n#{not_fully.size} projects are not fully funded:"
      not_fully.sort.each do |p|
        puts "#{p.name} ($#{p.current_funding})"
      end

      puts "\n#{not_fully.size} project(s) still need your help:"
      not_fully.sort.each do |p|
        puts "#{p.name} needs #{p.needed_funding} dollars."
      end
  end

  def to_s
    "There are #{@projects_ar.size} projects in #{@name}." 
  end
end

if __FILE__ == $0
project1 = Project.new("Project ABC", 3000, 500)
project2 = Project.new("Project LMN", 225, 25)
project3 = Project.new("Project XYZ", 100, 110)


my_project = FundRequest.new("VC-Friendly Start-up Projects.")

my_project.add_project(project1)
my_project.add_project(project2)
my_project.add_project(project3)

my_project.request_funding

end
end
