module FundRaise

require_relative '../../lib/fund_raise/pledge_pool'
require_relative '../../lib/fund_raise/fundable'

class Project
  include Fundable

  attr_accessor :name
  attr_reader :current_funding, :target_funding

  def initialize (name, target=	1000, funding=0)
    @name = name
    @current_funding = funding
    @target_funding = target
    @pledges_received = Hash.new(0)
  end

  def pledge_received(pledge)
    @pledges_received[pledge.name] += pledge.value
    add_funds(pledge.value)
    puts "#{@name} received a #{pledge.name} pledge worth $#{pledge.value}."
    puts "#{@name}'s pledges: #{@pledges_received}"
  end

  def each_given_pledge
    @pledges_received.each do |name, value|
      pledge = Pledge.new(name, value)
      yield pledge
    end
  end

  def needed_funding
    @target_funding - @current_funding
  end

  def self.from_csv(string)
    name, target, funding = string.split(',')
    player = Project.new(name, Integer(target), Integer(funding))
  end

  def to_csv
    "#{@name}, #{@target_funding}, #{@current_funding}"
  end

  def pledge_money
    @pledges_received.values.reduce(0, :+)
  end

  def total_funding  
    @current_funding + pledge_money
  end

  def time
   current_time = Time.new
   current_time.strftime("%A, %B, %d, %Y")
  end

  def <=>(other_project)
    needed_funding <=> other_project.needed_funding 
  end

  def to_s
    "#{@name} has $#{@current_funding} in funding towards a goal of $#{@target_funding}"
  end
end

if __FILE__ == $0
project1 = Project.new("Project ABC", 3000, 500)
project2 = Project.new("Project LMN", 225, 25)
project3 = Project.new("Project XYZ", 100, 110)

projects_ar = [project1, project2]

puts "There are #{projects_ar.size} projects in the array:"
projects_ar.each do |project|
  puts project
end
puts project1.remove_funds
puts project2.add_funds

projects_ar.each do |project|
  puts project
end

projects_ar.each do |project|
  if project.current_funding < 90
    puts "DELETE #{project.name}"
    projects_ar.delete(project)
  end
end
projects_ar.push(project3)

puts "\nThere are #{projects_ar.size} projects in the array."
projects_ar.each do |project|
  puts project
end

end
end
